@@ -40,9 +40,6 @@ class SOLID_EXPORT Battery : public DeviceInterface
     Q_PROPERTY(double voltage READ voltage NOTIFY voltageChanged)
     Q_PROPERTY(double temperature READ temperature NOTIFY temperatureChanged)
     Q_PROPERTY(Technology technology READ technology CONSTANT)
-    Q_PROPERTY(bool recalled READ isRecalled)
-    Q_PROPERTY(QString recallVendor READ recallVendor)
-    Q_PROPERTY(QString recallUrl READ recallUrl)
     Q_PROPERTY(QString serial READ serial CONSTANT)
     Q_PROPERTY(qlonglong remainingTime READ remainingTime NOTIFY remainingTimeChanged)
     Q_DECLARE_PRIVATE(Battery)
@@ -128,7 +125,7 @@ private:
      * @param backendObject the device interface object provided by the backend
      * @see Solid::Device::as()
      */
-    explicit Battery(QObject *backendObject);
+    SOLID_NO_EXPORT explicit Battery(QObject *backendObject);
 
 public:
     /**
@@ -154,19 +151,6 @@ public:
      */
     bool isPresent() const;
 
-#if SOLID_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * Indicates if this battery is currently present in its bay.
-     *
-     * @deprecated Since 5.0, use isPresent() instead.
-     */
-    SOLID_DEPRECATED_VERSION(5, 0, "Use Battery::isPresent()")
-    bool isPlugged() const
-    {
-        return isPresent();
-    }
-#endif
-
     /**
      * Retrieves the type of device holding this battery.
      *
@@ -288,30 +272,6 @@ public:
      */
     double temperature() const;
 
-    /**
-     * The battery may have been recalled by the vendor due to a suspected fault.
-     *
-     * @return true if the battery has been recalled, false otherwise
-     * @since 5.0
-     */
-    bool isRecalled() const;
-
-    /**
-     * The vendor that has recalled the battery.
-     *
-     * @return the vendor name that has recalled the battery
-     * @since 5.0
-     */
-    QString recallVendor() const;
-
-    /**
-     * The website URL of the vendor that has recalled the battery.
-     *
-     * @return the website URL of the vendor that has recalled the battery
-     * @since 5.0
-     */
-    QString recallUrl() const;
-
     /**
      * The serial number of the battery
      *
